@@ -1,10 +1,10 @@
 open! Core
 
 module List_with_max_len_one =
-  Protocol_version_header.For_test.Make_list_with_max_len (struct
-    let max_len = 1
-    let context = Info.of_string "Context"
-  end)
+Protocol_version_header.For_test.Make_list_with_max_len (struct
+  let max_len = 1
+  let context = Info.of_string "Context"
+end)
 
 let round_trips ~here lst =
   let serialized_with_regular_list =
@@ -30,7 +30,8 @@ let%expect_test "we can read regular lists sent over the wire and fail when we a
     print_s [%message (exn : Exn.t)];
     [%expect
       {|
-          (exn
-           (exn.ml.Reraised Context
-            (common.ml.Read_error "List_too_long / 2 (max 1)" 1)))|}]
+      (exn
+       (exn.ml.Reraised Context
+        (common.ml.Read_error "List_too_long / 2 (max 1)" 1)))
+      |}]
 ;;
