@@ -7,7 +7,7 @@ let magic_numbers =
 ;;
 
 let%test_unit "validate magic numbers" =
-  (* Magic numbers must fit into Ocaml integers (31 bits on 32 bit builds). *)
+  (* Magic numbers must fit into OCaml integers (31 bits on 32 bit builds). *)
   assert (List.for_all magic_numbers ~f:(fun n -> n <= Int.of_float ((2. ** 30.) -. 1.)));
   (* Magic numbers are not too small, so it doesn't clash with potential protocol
      version numbers. *)
@@ -31,5 +31,6 @@ let%expect_test "show the value of our magic numbers" =
     5521995
     4411474
     43244093
-    43437982 |}]
+    43437982
+    |}]
 ;;
