@@ -1,9 +1,9 @@
 open! Core
 
 let read
-      info
-      buf
-      (reader : Protocol_version_header.Known_protocol.t option Bin_prot.Type_class.reader)
+  info
+  buf
+  (reader : Protocol_version_header.Known_protocol.t option Bin_prot.Type_class.reader)
   =
   let pos_ref = ref 0 in
   match reader.read buf ~pos_ref with
@@ -39,18 +39,21 @@ let%expect_test "Test magic prefix reader" =
     {|
     bytes written to the buffer: 6
     any_magic_prefix -> known_protocol: Krb, bytes_read: 6
-    any_magic_prefix_from_fixed_bytes -> known_protocol: Krb, bytes_read: 6 |}];
+    any_magic_prefix_from_fixed_bytes -> known_protocol: Krb, bytes_read: 6
+    |}];
   test (Protocol_version_header.create_exn () ~protocol:Krb ~supported_versions:[ 1 ]);
   [%expect
     {|
     bytes written to the buffer: 7
     any_magic_prefix -> known_protocol: Krb, bytes_read: 7
-    any_magic_prefix_from_fixed_bytes -> known_protocol: Krb, bytes_read: 6 |}];
+    any_magic_prefix_from_fixed_bytes -> known_protocol: Krb, bytes_read: 6
+    |}];
   test
     (Protocol_version_header.create_exn () ~protocol:Rpc ~supported_versions:[ 1; 2; 3 ]);
   [%expect
     {|
     bytes written to the buffer: 9
     any_magic_prefix -> known_protocol: Rpc, bytes_read: 9
-    any_magic_prefix_from_fixed_bytes -> known_protocol: Rpc, bytes_read: 6 |}]
+    any_magic_prefix_from_fixed_bytes -> known_protocol: Rpc, bytes_read: 6
+    |}]
 ;;
